package com.ruoyi.system.mapper;

import com.ruoyi.common.core.domain.entity.ResidentInfo;

import java.util.List;


/**
 * 居住人员信息，存储居住人员的详细信息Mapper接口
 * 
 * @author boman
 * @date 2025-02-20
 */
public interface ResidentInfoMapper 
{
    /**
     * 查询居住人员信息，存储居住人员的详细信息
     * 
     * @param residentId 居住人员信息，存储居住人员的详细信息主键
     * @return 居住人员信息，存储居住人员的详细信息
     */
    public ResidentInfo selectResidentInfoByResidentId(Long residentId);

    /**
     * 查询居住人员信息，存储居住人员的详细信息列表
     * 
     * @param residentInfo 居住人员信息，存储居住人员的详细信息
     * @return 居住人员信息，存储居住人员的详细信息集合
     */
    public List<ResidentInfo> selectResidentInfoList(ResidentInfo residentInfo);

    public int selectCount(ResidentInfo residentInfo);

    /**
     * 新增居住人员信息，存储居住人员的详细信息
     * 
     * @param residentInfo 居住人员信息，存储居住人员的详细信息
     * @return 结果
     */
    public int insertResidentInfo(ResidentInfo residentInfo);

    /**
     * 修改居住人员信息，存储居住人员的详细信息
     * 
     * @param residentInfo 居住人员信息，存储居住人员的详细信息
     * @return 结果
     */
    public int updateResidentInfo(ResidentInfo residentInfo);

    /**
     * 删除居住人员信息，存储居住人员的详细信息
     * 
     * @param residentId 居住人员信息，存储居住人员的详细信息主键
     * @return 结果
     */
    public int deleteResidentInfoByResidentId(Long residentId);

    /**
     * 批量删除居住人员信息，存储居住人员的详细信息
     * 
     * @param residentIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteResidentInfoByResidentIds(Long[] residentIds);

    /**
     * 根据userId查询居住人员信息
     * @param userId
     * @return
     */
    public ResidentInfo selectResidentInfoByUserId(Long userId);

    void insertResidentInfoList(List<ResidentInfo> residentInfoList);
}
